#
# spec file for package msitools
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           msitools
Version:        0.97
Release:        lp152.3.8
Summary:        Tools to inspect and build Windows Installer (.MSI) files
License:        GPL-2.0-or-later
Group:          Productivity/Archiving/Compression
Url:            https://wiki.gnome.org/msitools
Source:         https://download.gnome.org/sources/msitools/%{version}/%{name}-%{version}.tar.xz
BuildRequires:  bison
BuildRequires:  intltool
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gio-2.0) >= 2.14
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gobject-introspection-1.0) >= 0.9.4
BuildRequires:  pkgconfig(libgcab-1.0) >= 0.1.10
BuildRequires:  pkgconfig(libgsf-1)
BuildRequires:  pkgconfig(libxml-2.0) >= 2.7
BuildRequires:  pkgconfig(uuid) >= 1.41.3
BuildRequires:  pkgconfig(vapigen) >= 0.16
Recommends:     %{name}-lang

%description
msitools is a set of programs to inspect and build Windows Installer
(.MSI) files.  It is based on libmsi, a portable library to read and
write .MSI files.

msitools plans to be a solution for packaging and deployment of
cross-compiled Windows applications.

%package -n libmsi0
Summary:        Library to inspect and build Windows Installer (.MSI) files
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n libmsi0
libmsi is a port of (and a subset of) Wine's implementation of the Windows
Installer.

%package -n typelib-1_0-Libmsi-1_0
Summary:        Introspection bindings for libmsi, a library to inspect and build .msi files
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description -n typelib-1_0-Libmsi-1_0
libmsi is a port of (and a subset of) Wine's implementation of the Windows
Installer.

%package devel
Summary:        Development files for libmsi, a library to inspect and build .msi files
License:        LGPL-2.1-or-later
Group:          Development/Libraries/C and C++
Requires:       %{name} = %{version}
Requires:       libmsi0 = %{version}
Requires:       typelib-1_0-Libmsi-1_0 = %{version}

%description devel
msitools is a set of programs to inspect and build Windows Installer
(.MSI) files.  It is based on libmsi, a portable library to read and
write .MSI files.  libmsi in turn is a port of (and a subset of) Wine's
implementation of the Windows Installer.

msitools can be used for packaging and deployment of
cross-compiled Windows applications.

%lang_package

%prep
%setup -q

%build
%configure \
  --disable-static
make %{?_smp_mflags} V=1

%install
%make_install
%find_lang %{name} %{?no_lang_C}
find %{buildroot} -type f -name "*.la" -delete -print

%post -n libmsi0 -p /sbin/ldconfig
%postun -n libmsi0 -p /sbin/ldconfig

%files
%doc AUTHORS COPYING COPYING.LIB NEWS README
%{_bindir}/msibuild
%{_bindir}/msidiff
%{_bindir}/msidump
%{_bindir}/msiextract
%{_bindir}/msiinfo
%{_bindir}/wixl
%{_bindir}/wixl-heat
%{_datadir}/bash-completion/completions/msitools
%{_datadir}/wixl-%{version}/

%files lang -f %{name}.lang

%files -n libmsi0
%{_libdir}/libmsi.so.0*

%files -n typelib-1_0-Libmsi-1_0
%{_libdir}/girepository-1.0/Libmsi-1.0.typelib

%files devel
%{_includedir}/libmsi-1.0/
%{_libdir}/libmsi.so
%{_libdir}/pkgconfig/libmsi-1.0.pc
%{_datadir}/gir-1.0/*.gir
%{_datadir}/vala/vapi/

%changelog
* Sun Feb 18 2018 jengelh@inai.de
- Update summaries, and let description say what it does now,
  not in the future.
* Fri Feb 16 2018 aloisio@gmx.com
- Update to version v0.97
  * fix potential crash in read_properties
  * fix double-frees in libmsi_summary_info_finalize
  * wixl-heat: escape $ in filename, bgo#756904
  * correctly parse dates, bgo#752860
  * msiextract: fix extracting to SourceDir, bgo#773935
  * wix updates: glib2, jasper, adwaita
  * translation updates, build-sys fixes
  version 0.96
  * Add libvirt-glib.wxi
  * Update nettle to 3.2.1
  * Fix implicit declaration of mkdir in the testdatabase
  * Disable -Wbad-function-cast (build-sys)
  * Removed unneeded workaround (build-sys)
  * Remove non-existent libvirt-glib translations
  * Fix translations's path for libvirt-glib
  * Add adwaita-icon-theme.wxi
  * Add pcre.wxi
  * Add pcre as glib2 dependency
  * Remove virt-host-validade (libvirt.wxi)
  * Update libspice-client-gtk dll version
  * Add support to external cab handling (msiextract)
  * Update adwaita and glib for f25
  * Update git.mk
  * Fix "make -j"
  * Update gstreamer1 to 1.10.0
  * Update gstreamer1-plugins-bad-free to 1.10.0
  * Drop spice-gtk.wxi (spice-gtk2)
  * Updade nettle to 3.3
  * Remove libidn's locale data
  * Translations
  version 0.95
  * Add libepoxy.wxi
  * Update gtk3.wxi
  * Update libcacad.wxi
  * Update nss.wxi
  * Update nspr.wxi
  * Update pango.wxi
  * Update gnutls.wxi
  * Update nettle.wxi
  * Update libvirt.wxi
  * Update fontconfig.wxi
  * Add bzip2.wxi
  * Update freetype.wxi
  * Update gstreamer1.wxi
  * Update gstreamer1-plugins-base.wxi
  * Update gstreamer1-plugins-bad-free.wxi
  * Translations
  version 0.94
  * Add support for Signature table
  * Add support for scheduling AppSearch
  * Add support for MsiFileHash table
  * Update libpng wxi
  * Add winpthreads wxi
  * Update libvirt wxi
  * Add opus wxi
  * Add spice-glib wxi
  * Update libffi wxi
  * Update glib2 wxi
  * Update libsoup wxi
  * Add sqlite
  * Update nettle wxi
  * Update gtk2 wxi
  * Update libgcrypt wxi
  * Add option to make packages win64-aware
  * Treat EDITTIME property as filetime in parse_prop
  * Add gtk3 wxi
  * Add spice-gtk3 wxi
  * Add gtk-vnc2 wxi
  * Add rest wxi
  * Add libgovirt wxi
  * Add gstreamer1 exi
  * Add gstreamer1-plugins-base wxi
  * Add gstreamer1-plugins-good wxi
  * Add gstreamer1-plugins-bad-free wxi
  * Update spice-glib wxi
  * Update gcc wxi
  * Fix wix close tag when no component groups are specified
    (wixl-heat)
  * Build clean-ups
  * Misc bug fixes
  * Translations
- Spec cleanup
* Wed Feb 22 2017 mpluskal@suse.com
- Cleanup spec file
* Wed Dec 10 2014 vuntz@opensuse.org
- Initial package (0.93)
